==> kvpnc_0.8.orig.tar.gz: kvpnc-0.8/src/utils.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Christoph Thielecke                             *
 *   crissi99@gmx.de                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef __UTILS_H__
#define __UTILS_H__

#include <qobject.h>
#include <qprocess.h>
#include <qdns.h>
#include <qvaluelist.h>
#include "kvpncconfig.h"
#include "kvpnc.h"
#include "toolinfo.h"
#include <qstringlist.h>



/**
Provides various help functions.
 
@author Christoph Thielecke
*/
class Utils : public QObject
{
	Q_OBJECT
public:
	Utils(QObject *parent = 0, const char *name = 0);

	~Utils();

	bool isValidIPv4Adress(QString Address);
	bool tunDevExists();
	bool createTunDev();
  bool loadKernelModule(QString Name,QApplication *app);
	bool isValidNetworkDevice(QString NetworkDevice);
	QPtrList<ToolInfo>* getToolList();
	QString resolveName(QString Name,QApplication *app);
	QString removeSpecialCharsForFilename(QString filename);
	QString decodeHtml(QString htmlstring);

public slots:
	void readStdOutCreateTunDev();
	void readStdErrCreateTunDev();
	void readStdOutNetworkDeviceTest();
	void readStdErrNetworkDeviceTest();
	void readStdOutLoadKernelModule();
	void readStdErrLoadKernelModule();
	void readStdOutToolsTest();
	void readStdErrToolsTest();
	void dnsLookupHelper();

private:
	bool validNetworkDevice;
	bool modprobeSuccess;
	bool toolsTestSuccess;
	QString tooltest_logfile;
	QProcess *ModprobeProcess;
	QProcess *createProcess;
	QProcess *NetworkDeviceTestProcess;
	QProcess *toolsTestProcess;
	QString resolvedIP;
	bool resolveFinished;
	QDns *myDns;
	QValueList<QHostAddress> list;
	QStringList *env;


};

#endif

==> kvpnc_0.8.2.1.orig.tar.gz: kvpnc-0.8.2.1.orig/src/utils.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Christoph Thielecke                             *
 *   crissi99@gmx.de                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef __UTILS_H__
#define __UTILS_H__

#include <qobject.h>
#include <qprocess.h>
#include <qdns.h>
#include <qvaluelist.h>
#include "kvpncconfig.h"
#include "kvpnc.h"
#include "toolinfo.h"
#include <qstringlist.h>
#include <ktempfile.h>



/**
Provides various help functions.
 
@author Christoph Thielecke
*/
class Utils : public QObject
{
	Q_OBJECT
public:
	Utils(KVpncConfig* config,QObject *parent = 0, const char *name = 0);

	~Utils();

	bool isValidIPv4Adress(QString Address);
	bool tunDevExists();
	bool createTunDev();
  bool loadKernelModule(QString Name,QApplication *app);
	bool isValidNetworkDevice(QString NetworkDevice);
	QPtrList<ToolInfo>* getToolList();
	ToolInfo* getToolInfo(KVpncConfig *GlobalConfig, QString name);
	QString resolveName(QString Name,QApplication *app);
	QString removeSpecialCharsForFilename(QString filename);

public slots:
	void readStdOutCreateTunDev();
	void readStdErrCreateTunDev();
	void readStdOutNetworkDeviceTest();
	void readStdErrNetworkDeviceTest();
	void readStdOutLoadKernelModule();
	void readStdErrLoadKernelModule();
	void readStdOutToolsTest();
	void readStdErrToolsTest();
	void dnsLookupHelper();
	void processHasFinished();

private:
	bool validNetworkDevice;
	bool modprobeSuccess;
	bool toolsTestSuccess;
	QString tooltest_logfile;
	QProcess *ModprobeProcess;
	QProcess *createProcess;
	QProcess *NetworkDeviceTestProcess;
	QProcess *toolsTestProcess;
	QString resolvedIP;
	bool resolveFinished;
	QDns *myDns;
	QValueList<QHostAddress> list;
	QStringList *env;
	KVpncConfig *config;
	KTempFile *tmpfile;
	bool retrieveValidNetworkdevice;

};

#endif
